containertools.split_container_cyclically_by_counts_and_do_not_fracture_crossing_spanners
=========================================================================================

.. autofunction:: abjad.tools.containertools.split_container_cyclically_by_counts_and_do_not_fracture_crossing_spanners
